@@ -1,7 +1,7 @@
 package Encode::DIN66003;
 use vars qw($VERSION);
-$VERSION = "0.01";
- 
+$VERSION = "0.02";
+
 use Encode;
 use XSLoader;
 XSLoader::load(__PACKAGE__,$VERSION);
@@ -12,13 +12,13 @@ __END__
 =encoding UTF-8
 
 =head1 NAME
- 
+
 Encode::DIN66003 - Encoding according to DIN 66003
- 
+
 =head1 SYNOPSIS
 
   use Encode::DIN66003;
-  
+
   # If your terminal is UTF-8
   print decode('DIN66003', 'Hello W|rld!'); # Hello Wörld
 
@@ -29,10 +29,16 @@ Encode::DIN66003 - Encoding according to DIN 66003
 
 L<Encode>
 
+CP1011 (IBM) and CP20106 (Microsoft)
+
+L<https://de.wikipedia.org/wiki/DIN_66003>
+
+L<https://en.wikipedia.org/wiki/Code_page_1011>
+
 =head1 REPOSITORY
 
 The public repository of this module is
-L<https://github.com/Corion/www-mechanize-phantomjs>.
+L<https://github.com/Corion/Encode-DIN66003>.
 
 =head1 SUPPORT
 
